<?php

namespace FiloBlu\Cegid\Controller\Seller;

use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Action\Context;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\App\ResourceConnection;
use Magento\Framework\App\ResponseInterface;
use Magento\Framework\Controller\Result\JsonFactory;
use Magento\Framework\Controller\ResultInterface;
use Magento\Framework\Exception\NotFoundException;
use Magento\Store\Model\ScopeInterface;
use Zend_Db;

/**
 * Class Search
 * @package FiloBlu\Cegid\Controller\Frontend\Seller
 */
class Search extends Action
{
    const XML_PATH_ENABLED = 'filoblu_cegid/seller/enable';
    /**
     * @var JsonFactory
     */
    protected $resultJsonFactory;
    /**
     * @var ResourceConnection
     */
    protected $resourceConnection;
    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;

    /**
     * Search constructor.
     * @param Context $context
     * @param JsonFactory $resultJsonFactory
     * @param ResourceConnection $resourceConnection
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(Context $context,
                                JsonFactory $resultJsonFactory,
                                ResourceConnection $resourceConnection,
                                ScopeConfigInterface $scopeConfig
    )
    {
        $this->resultJsonFactory = $resultJsonFactory;
        $this->resourceConnection = $resourceConnection;
        $this->scopeConfig = $scopeConfig;
        parent::__construct($context);
    }

    /**
     * Execute action based on request and return result
     *
     * Note: Request will be added as operation argument in future
     *
     * @return ResultInterface|ResponseInterface
     * @throws NotFoundException
     */
    public function execute()
    {
        $searchParam = $this->getRequest()->getParam('q');

        $connection = $this->resourceConnection->getConnection();

        $table = $connection->getTableName('filoblu_cegid_seller');
        $query = $connection->select()->from($table, ['label' => 'nickname', 'value' => 'cegid_id'])->where('nickname LIKE ?', "%{$searchParam}%");

        $result = $connection->fetchAll($query, [], Zend_Db::FETCH_ASSOC);
        return $this->resultJsonFactory->create()->setData($result);

    }

    /**
     * Dispatch request
     *
     * @param RequestInterface $request
     * @return ResponseInterface
     * @throws NotFoundException
     */
    public function dispatch(RequestInterface $request)
    {
        if ($this->scopeConfig->isSetFlag(self::XML_PATH_ENABLED, ScopeInterface::SCOPE_STORE)) {
            return parent::dispatch($request);
        }

        throw new NotFoundException(__('Page not found.'));
    }
}