<?php

namespace FiloBlu\Cegid\Model;

use FiloBlu\Cegid\Api\Data\SellerInterface;
use FiloBlu\Cegid\Api\SellerRepositoryInterface;
use Magento\Framework\App\ResourceConnection;
use Magento\Framework\Exception\NoSuchEntityException;
use Zend_Db;

/**
 * Class SellerRepository
 * @package FiloBlu\Cegid\Model
 */
class SellerRepository implements SellerRepositoryInterface
{
    const TABLE = 'filoblu_cegid_seller';
    /**
     * @var SellerFactory
     */
    protected $sellerFactory;
    /**
     * @var ResourceConnection
     */
    protected $resourceConnection;

    /**
     * SellerRepository constructor.
     * @param ResourceConnection $resourceConnection
     * @param SellerFactory $sellerFactory
     */
    public function __construct(ResourceConnection $resourceConnection, SellerFactory $sellerFactory)
    {
        $this->resourceConnection = $resourceConnection;
        $this->sellerFactory = $sellerFactory;
    }

    /**
     * @param string $id
     * @return Seller
     * @throws NoSuchEntityException
     */
    public function get($id)
    {
        $connection = $this->resourceConnection->getConnection();
        $table = $connection->getTableName(self::TABLE);
        $select = $this->resourceConnection->getConnection()->select()->from($table)->where('cegid_id = :id');
        $data = $connection->fetchRow($select, ['id' => $id], Zend_Db::FETCH_ASSOC);

        if ($data === null || empty($data)) {
            throw new NoSuchEntityException(__("Could not find seller with id '{$id}'"));
        }

        return $this->fromArray($data);
    }

    public function fromArray($data)
    {
        return $this->sellerFactory->create()
            ->setStoreCode($data['store_code'])
            ->setCegidId($data['cegid_id'])
            ->setNickName($data['nickname']);
    }

    /**
     * @param $name
     * @return SellerInterface[]
     */
    public function searchByName($name)
    {
        $connection = $this->resourceConnection->getConnection();

        $table = $connection->getTableName(self::TABLE);
        $query = $connection->select()->from($table)->where('`nickname` LIKE :nickname');

        $result = $connection->fetchAll($query, ['nickname' => "%{$name}%"], Zend_Db::FETCH_ASSOC);

        $items = [];
        foreach ($result as $item) {
            $items[] = $this->fromArray($item);
        }

        return $items;
    }

    /**
     * @param SellerInterface $seller
     * @return mixed
     */
    public function save(SellerInterface $seller)
    {
        // TODO: Implement save() method.
    }
}